@@ -1,6 +1,6 @@
 package DateTime::Format::GnuAt;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use strict;
 use warnings;
@@ -43,8 +43,10 @@ sub new {
 
 sub _reset {
     my ($self, $opts) = @_;
-    %$self = ();
-    $self->{now} = delete($opts->{now}) // DateTime->now(time_zone => 'local');
+    %{$self} = ();
+    my $now = delete $opts->{now};
+    $self->{now} = (defined $now ? $now->clone : DateTime->now(time_zone => 'local'));
+    $self->{now}->set(second => 0);
 }
 
 sub parse_datetime {
@@ -145,7 +147,7 @@ sub _parse_date {
     }
     elsif (/\Gnow\b/gci) {
         # NOW
-        $self->{now} = 1;
+        $self->{is_now} = 1;
         $self->{date} = $now;
         return 1;
     }
